{******************************************************************************}
{*                                                                            *}
{*  Copyright (c) 2002, NVIDIA Corporation.                                   *}
{*                                                                            *}
{*  Files:    ICgFXEffect.h                                                   *}
{*  Content:  NVIDIA CgFX interface include files                             *}
{*                                                                            *}
{*  NVIDIA "Cg" Release 1.1 ObjectPascal adaptation by Alexey Barkovoy        *}
{*  E-Mail: clootie@reactor.ru                                                *}
{*                                                                            *}
{*  Modified: 21-Mar-2003                                                     *}
{*                                                                            *}
{*  Latest version can be downloaded from:                                    *}
{*     http://clootie.narod.ru                                                *}
{*                                                                            *}
{******************************************************************************}
{                                                                              }
{ Obtained through: Joint Endeavour of Delphi Innovators (Project JEDI)        }
{                                                                              }
{ The contents of this file are used with permission, subject to the Mozilla   }
{ Public License Version 1.1 (the "License"); you may not use this file except }
{ in compliance with the License. You may obtain a copy of the License at      }
{ http://www.mozilla.org/MPL/MPL-1.1.html                                      }
{                                                                              }
{ Software distributed under the License is distributed on an "AS IS" basis,   }
{ WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for }
{ the specific language governing rights and limitations under the License.    }
{                                                                              }
{ Alternatively, the contents of this file may be used under the terms of the  }
{ GNU Lesser General Public License (the  "LGPL License"), in which case the   }
{ provisions of the LGPL License are applicable instead of those above.        }
{ If you wish to allow use of your version of this file only under the terms   }
{ of the LGPL License and not to allow others to use your version of this file }
{ under the MPL, indicate your decision by deleting  the provisions above and  }
{ replace  them with the notice and other provisions required by the LGPL      }
{ License.  If you do not delete the provisions above, a recipient may use     }
{ your version of this file under either the MPL or the LGPL License.          }
{                                                                              }
{ For more information about the LGPL: http://www.gnu.org/copyleft/lesser.html }
{                                                                              }
{******************************************************************************}
(*********************************************************************NVMH3****
Path:  E:\Documents and Settings\sdomine\My Documents\CGFX_Beta_Runtime\include
File:  ICgFXEffect.h

Copyright NVIDIA Corporation 2002
TO THE MAXIMUM EXTENT PERMITTED BY APPLICABLE LAW, THIS SOFTWARE IS PROVIDED
*AS IS* AND NVIDIA AND ITS SUPPLIERS DISCLAIM ALL WARRANTIES, EITHER EXPRESS
OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS FOR A PARTICULAR PURPOSE.  IN NO EVENT SHALL NVIDIA OR ITS SUPPLIERS
BE LIABLE FOR ANY SPECIAL, INCIDENTAL, INDIRECT, OR CONSEQUENTIAL DAMAGES
WHATSOEVER (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS OF BUSINESS PROFITS,
BUSINESS INTERRUPTION, LOSS OF BUSINESS INFORMATION, OR ANY OTHER PECUNIARY LOSS)
ARISING OUT OF THE USE OF OR INABILITY TO USE THIS SOFTWARE, EVEN IF NVIDIA HAS
BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.


Comments:




******************************************************************************)

unit cgFX;

interface

uses
  Windows;

{$MINENUMSIZE 4}
{$ALIGN ON}

(*$HPPEMIT '#include "ICgFXEffect.h"' *)

const
  CgFX_DLL = 'CgFXab.dll';

const
  CGFX_MAX_DIMENSIONS = 4;
  {$EXTERNALSYM CGFX_MAX_DIMENSIONS}

//////////////////////////////////////////////////////////////////////////////
// Types /////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////

type
  _CgFXPARAMETERTYPE =
   (
    CgFXPT_UNKNOWN {= 0},
    CgFXPT_BOOL,
    CgFXPT_INT,
    CgFXPT_FLOAT,
    CgFXPT_DWORD,
    CgFXPT_STRING,

    // Ref counted objects; Can be accessed as objects or as strings
    CgFXPT_TEXTURE,
    CgFXPT_CUBETEXTURE,
    CgFXPT_VOLUMETEXTURE,
    CgFXPT_VERTEXSHADER,
    CgFXPT_PIXELSHADER,

    // Complex type
    CgFXPT_STRUCT

    // force 32-bit size enum
    //CgFXPT_FORCE_DWORD      = 0x7fffffff
  );
  {$EXTERNALSYM _CgFXPARAMETERTYPE}
  CgFXPARAMETERTYPE = _CgFXPARAMETERTYPE;
  {$EXTERNALSYM CgFXPARAMETERTYPE}
  TCgFXParameterType = _CgFXPARAMETERTYPE;
  PCgFXParameterType = ^TCgFXParameterType;


  PCgFXEffectDesc = ^TCgFXEffectDesc;
  _CgFXEffect_DESC = packed record
    Parameters: LongWord; // Number of parameters
    Techniques: LongWord; // Number of techniques
    Functions: LongWord;  // Number of functions
  end;
  {$EXTERNALSYM _CgFXEffect_DESC}
  CgFXEffect_DESC = _CgFXEffect_DESC;
  {$EXTERNALSYM CgFXEffect_DESC}
  TCgFXEffectDesc = _CgFXEffect_DESC;

  PCgFXParameterDesc = ^TCgFXParameterDesc;
  _CgFXPARAMETER_DESC = packed record
    Name: PAnsiChar;                    // Parameter name.
    Index: PAnsiChar;                   // Parameter index (cast to LPCSTR)

    // Usage
    Semantic: PAnsiChar;                // Semantic meaning

    // Type
    _Type: TCgFXParameterType;          // Parameter type
    Dimension: array[0..CGFX_MAX_DIMENSIONS-1] of LongWord; // Elements in array
    Bytes: LongWord;                    // Total size in bytes

    // Annotations
    Annotations: LongWord;              // Number of annotations.
  end;
  {$EXTERNALSYM _CgFXPARAMETER_DESC}
  CgFXPARAMETER_DESC = _CgFXPARAMETER_DESC;
  {$EXTERNALSYM CgFXPARAMETER_DESC}
  TCgFXParameterDesc = _CgFXPARAMETER_DESC;

  PCgFXAnnotationDesc = ^TCgFXAnnotationDesc;
  _CgFXANNOTATION_DESC = packed record
    Name: PAnsiChar;                        // Annotation name
    Index: PAnsiChar;                       // Annotation index (cast to LPCSTR)
    Value: Pointer;                         // Annotation value (cast to LPCVOID)

    // Type
    _Type: TCgFXParameterType;              // Annotation type
    Dimension: array[0..CGFX_MAX_DIMENSIONS-1] of LongWord;   // Elements in array
    Bytes: LongWord;                        // Total size in bytes
  end;
  {$EXTERNALSYM _CgFXANNOTATION_DESC}
  CgFXANNOTATION_DESC = _CgFXANNOTATION_DESC;
  {$EXTERNALSYM CgFXANNOTATION_DESC}
  TCgFXAnnotationDesc = _CgFXANNOTATION_DESC;

  PCgFXTechniqueDesc = ^TCgFXTechniqueDesc;
  _CgFXTECHNIQUE_DESC = packed record
    Name: PAnsiChar;                        // Technique name
    Index: PAnsiChar;                       // Technique index (cast to LPCSTR)

    Properties: LongWord;                   // Number of properties
    Passes: LongWord;                       // Number of passes
  end;
  {$EXTERNALSYM _CgFXTECHNIQUE_DESC}
  CgFXTECHNIQUE_DESC = _CgFXTECHNIQUE_DESC;
  {$EXTERNALSYM CgFXTECHNIQUE_DESC}
  TCgFXTechniqueDesc = _CgFXTECHNIQUE_DESC;

  PCgFXPassDesc = ^TCgFXPassDesc;
  _CgFXPASS_DESC = packed record
    Name: PAnsiChar;                        // Pass name
    Index: PAnsiChar;                       // Pass index (cast to LPCSTR)
  end;
  {$EXTERNALSYM _CgFXPASS_DESC}
  CgFXPASS_DESC = _CgFXPASS_DESC;
  {$EXTERNALSYM CgFXPASS_DESC}
  TCgFXPassDesc = _CgFXPASS_DESC;

  _CgFXMode = (
    CgFX_Unknown,
    CgFX_OpenGL,
    CgFX_Direct3D8,
    CgFX_Direct3D9
  );
  {$EXTERNALSYM _CgFXMode}
  CgFXMode = _CgFXMode;
  {$EXTERNALSYM CgFXMode}
  TCgFXMode = _CgFXMode;
  PCgFXMode = ^TCgFXMode;

  //////////////////////////////////////////////////////////////////////////////
  // Base Effect ///////////////////////////////////////////////////////////////
  //////////////////////////////////////////////////////////////////////////////
  // base interface. extended by Effect and EffectCompiler.
  //////////////////////////////////////////////////////////////////////////////
  ICgFXBaseEffect = interface(IUnknown)
    // Descriptions
    (* Return description of effect *)
    function GetDesc(out pDesc: TCgFXEffectDesc): HResult; stdcall;
    (* Return description of the named/indexed parameter *)
    function GetParameterDesc(hParameter: PAnsiChar; out pDesc: TCgFXParameterDesc): HResult; stdcall;
    (* Return description of the named/indexed annotation *)
    function GetAnnotationDesc(hParameter, pAnnotation: PAnsiChar; out pDesc: TCgFXAnnotationDesc): HResult; stdcall;
    (* Return description of the named/indexed technique *)
    function GetTechniqueDesc(hTechnique: PAnsiChar; out pDesc: TCgFXTechniqueDesc): HResult; stdcall;
    (* Return description of pass for given technique *)
    function GetPassDesc(hPass: PAnsiChar; out pDesc: TCgFXPassDesc): HResult; stdcall;

    // Get/Set Parameter
    function SetValue(pName: PAnsiChar; pData: Pointer; Bytes: LongWord): HResult; stdcall;
    function GetValue(pName: PAnsiChar; pData: Pointer; Bytes: LongWord): HResult; stdcall;
    (*
    virtual HRESULT SetValueTranspose(LPCSTR pName, LPCVOID pData, UINT Bytes) = 0;
    virtual HRESULT GetValueTranspose(LPCSTR pName, LPVOID pData, UINT Bytes) = 0;
    *)

    function SetFloat(pName: PAnsiChar; f: Single): HResult; stdcall;
    function GetFloat(pName: PAnsiChar; out pf: Single): HResult; stdcall;
    function SetVector(pName: PAnsiChar; pVector: PSingle; vecSize: LongWord): HResult; stdcall;
    function GetVector(pName: PAnsiChar; pVector: PSingle; out vecSize: LongWord): HResult; stdcall;
    function SetMatrix(pName: PAnsiChar; pMatrix: PSingle; nRows, nCols: LongWord): HResult; stdcall;
    function GetMatrix(pName: PAnsiChar; pMatrix: PSingle; out nRows, nCols: LongWord): HResult; stdcall;
    //virtual HRESULT SetMatrixTranspose(LPCSTR pName, const float* pMatrix, UINT nRows, UINT nCols) = 0;
    //virtual HRESULT GetMatrixTranspose(LPCSTR pName, float* pMatrix, UINT* nRows, UINT* nCols) = 0;

    function SetDword(pName: PAnsiChar; dw: DWORD): HResult; stdcall;
    function GetDword(pName: PAnsiChar; out dw: DWORD): HResult; stdcall;

    function SetBool(pName: PAnsiChar; bvalue: BOOL): HResult; stdcall;
    function GetBool(pName: PAnsiChar; out bvalue: BOOL): HResult; stdcall;

    function SetString(pName: PAnsiChar; pString: PAnsiChar): HResult; stdcall;
    function GetString(pName: PAnsiChar; out ppString: PAnsiChar): HResult; stdcall;
    //virtual HRESULT SetTexture1D(LPCSTR pName, DWORD textureHandle) = 0;
    //virtual HRESULT GetTexture1D(LPCSTR pName, DWORD* textureHandle) = 0;
    function SetTexture(pName: PAnsiChar; textureHandle: DWORD): HResult; stdcall;
    function GetTexture(pName: PAnsiChar; out textureHandle: DWORD): HResult; stdcall;
    (*
    virtual HRESULT SetCubeTexture(LPCSTR pName, DWORD textureHandle) =0;
    virtual HRESULT GetCubeTexture(LPCSTR pName, DWORD* textureHandle) = 0;
    virtual HRESULT SetVolumeTexture(LPCSTR pName, DWORD textureHandle) = 0;
    virtual HRESULT GetVolumeTexture(LPCSTR pName, DWORD* textureHandle) = 0;
    *)

    function SetVertexShader(pName: PAnsiChar; vsHandle: DWORD): HResult; stdcall;
    function GetVertexShader(pName: PAnsiChar; out vsHandle: DWORD): HResult; stdcall;

    function SetPixelShader(pName: PAnsiChar; psHandle: DWORD): HResult; stdcall;
    function GetPixelShader(pName: PAnsiChar; out psHandle: DWORD): HResult; stdcall;
  end;

  ICgFXEffect = interface(ICgFXBaseEffect)
    // Set/get current technique:
    function SetTechnique(pTechnique: PAnsiChar): HResult; stdcall;
    function GetTechnique(out ppTechnique: PAnsiChar): HResult; stdcall;
    // Validate current technique:
    function Validate: HResult; stdcall;
    // Returns the number of passes in pPasses:
    function _Begin(pPasses: PLongWord; Flags: DWORD): HResult; stdcall; 
    function Pass(passNum: LongWord): HResult; stdcall;
    function _End: HResult; stdcall;

    function CloneEffect(out ppNewEffect: ICgFXEffect): HResult; stdcall;
    (*
    virtual HRESULT FindNextValidTechnique(LPCSTR pTechnique, CgFXTECHNIQUE_DESC* pDesc) = 0;
    *)

    function GetDevice(out ppDevice: Pointer): HResult; stdcall;
    function OnLostDevice: HResult; stdcall;
    function OnResetDevice: HResult; stdcall;
  end;

  ICgFXEffectCompiler = interface(ICgFXBaseEffect)
    // Compilation
    function CompileEffect(Flags: DWORD; out ppEffect: ICgFXEffect; ppCompilationErrors: PPChar): HResult; stdcall;
  end;



function CgFXCreateEffect(
    pSrcData: PAnsiChar;
    Flags: DWORD;
    out ppEffect: ICgFXEffect;
    ppCompilationErrors: PPChar): HResult; cdecl; external CgFX_DLL name 'CgFXCreateEffect_BCB';
{$EXTERNALSYM CgFXCreateEffect}

function CgFXCreateEffectFromFileA(
    pSrcFile: PAnsiChar;
    Flags: DWORD;
    out ppEffect: ICgFXEffect;
    ppCompilationErrors: PPChar): HResult; cdecl; external CgFX_DLL name 'CgFXCreateEffectFromFileA_BCB';
{$EXTERNALSYM CgFXCreateEffectFromFileA}

function CgFXCreateEffectCompiler(
    pSrcData: PAnsiChar;
    Flags: DWORD;
    out ppEffectCompiler: ICgFXEffectCompiler;
    ppCompilationErrors: PPChar): HResult; cdecl; external CgFX_DLL name 'CgFXCreateEffectCompiler_BCB';
{$EXTERNALSYM CgFXCreateEffectCompiler}

function CgFXCreateEffectCompilerFromFileA(
    pSrcFile: PAnsiChar;
    Flags: DWORD;
    out ppEffectCompiler: ICgFXEffectCompiler;
    ppCompilationErrors: PPChar): HResult; cdecl; external CgFX_DLL name 'CgFXCreateEffectCompilerFromFileA_BCB';
{$EXTERNALSYM CgFXCreateEffectCompilerFromFileA}

function CgFXSetDevice(pDeviceName: PChar; pDevice: Pointer): HResult; cdecl; external CgFX_DLL name 'CgFXSetDevice_BCB';
{$EXTERNALSYM CgFXSetDevice}
function CgFXFreeDevice(pDeviceName: PChar; pDevice: Pointer): HResult; cdecl; external CgFX_DLL name 'CgFXFreeDevice_BCB';
{$EXTERNALSYM CgFXFreeDevice}
function CgFXGetErrors(out ppErrors: PChar): HResult; cdecl; external CgFX_DLL name 'CgFXGetErrors_BCB';
{$EXTERNALSYM CgFXGetErrors}
function CgFXRelease: HResult; cdecl; external CgFX_DLL name 'CgFXRelease_BCB';
{$EXTERNALSYM CgFXRelease}

implementation

end.

